<?php

function dygrid( $prefix, $w_gutter, $w_column, $w_gap, $w_padding, $n_columns )
{
	header( 'Content-type: text/css' );

	println( "/*" );
	println( " * Dygrid | Dynamic Grid Generator" );
	println( " * " );
	println( " *    prefix: $prefix" );
	println( " *  w_gutter: $w_gutter"  );
	println( " *  w_column: $w_column" );
	println( " *     w_gap: $w_gap" );
	println( " * w_padding: $w_padding" );
	println( " * n_columns: $n_columns" );
	println( "*/" );

	println();
	println( "\t.absolute                    { position:absolute; }" );
	println( "\t.fixed                       { position:fixed;    }" );
	println( "\t.relative                    { position:relative; }" );
	println( "\t.sticky                      { position:sticky;   }" );
	println();
	println( "\t.center                      { margin-left:auto; margin-right:auto; }" );
	println();
	println( "\t.valign-outer                { display:table; width:100%; height:100%; }" );
	println();
	println( "\t.valign-outer .valign-top    { display:table-cell; vertical-align:top;    }" );
	println( "\t.valign-outer .valign-middle { display:table-cell; vertical-align:middle; }" );
	println( "\t.valign-outer .valign-bottom { display:table-cell; vertical-align:bottom; }" );
	println();

	printWidths  ( $prefix, $w_column, $w_gap, $n_columns, $w_gutter );
	printSpans   ( $prefix, $w_column, $w_gap, $n_columns );
	printXSpans  ( $prefix, $w_column, $w_gap, $n_columns );
	printZSpans  ( $prefix, $w_column, $w_gap, $n_columns );
	printOffsets ( $prefix, $w_column, $w_gap, $n_columns );
	printElements( $prefix, $w_column, $w_gap, $n_columns, $w_padding );
}

function printWidths( $prefix, $w_column, $w_gap, $n_columns, $w_gutter )
{
	$c = ($w_column * $n_columns) + ($w_gap * ($n_columns - 1));
	$p = $c + (2 * $w_gutter );
	$m = $p / 2;

	println( sprintf( "%10s %14s {     width:%s; }", ".$prefix", ".c_width  ", $c . "px" ) );
	println( sprintf( "%10s %14s {     width:%s; }", ".$prefix", ".p_width  ", $p . "px" ) );
	println();
	println( sprintf( "%10s %14s { max-width:%s; }", ".$prefix", ".c_widthr ", $c . "px" ) );
	println( sprintf( "%10s %14s { max-width:%s; }", ".$prefix", ".p_widthr ", $p . "px" ) );
	println();
	println( sprintf( "%10s %14s { min-width:%s; }", ".$prefix", ".p_widthr ", $m . "px" ) );
	println();
}

function printSpans( $prefix, $w_column, $w_gap, $n_columns )
{
	$z_gap = $w_gap / 2;

	println( sprintf( "%10s  .row:before, .$prefix  .row:after { display:table; content:''; }", ".$prefix" ) );
	println( sprintf( "%10s  .row:after                        { clear:both;                }", ".$prefix" ) );
	println( sprintf( "%10s .xrow:before, .$prefix .xrow:after { display:table; content:''; }", ".$prefix" ) );
	println( sprintf( "%10s .xrow:after                        { clear:both;                }", ".$prefix" ) );
	println( sprintf( "%10s .zrow:before, .$prefix .zrow:after { display:table; content:''; }", ".$prefix" ) );
	println( sprintf( "%10s .zrow:after                        { clear:both;                }", ".$prefix" ) );
	println();

	println( sprintf( "%10s %14s { margin-top:  %6s; }",  ".$prefix", ".vgap ", " " . $w_gap . "px" ) );
	println( sprintf( "%10s %14s { margin-left: %6s; }",  ".$prefix", " .row ", "-" . $w_gap . "px" ) );
	println( sprintf( "%10s %14s { margin-left: %6s; }",  ".$prefix", ".xrow ", "0"          . "px" ) );
	println( sprintf( "%10s %14s { margin-left: %6s; }",  ".$prefix", ".zrow ", "-" . $z_gap . "px" ) );
	println( sprintf( "%10s %14s { margin-right:%6s; }", ".$prefix", ".zrow ", "-" . $z_gap . "px" ) );
	println( sprintf( "%10s %14s { margin-left: %6s; }",  ".$prefix", ".span ",       $w_gap . "px" ) );
	println( sprintf( "%10s %14s { float:left; }",       ".$prefix", ".span " ) );
	println( sprintf( "%10s %14s { float:left; }",       ".$prefix", ".xspan " ) );

	println();

	println( sprintf( "%10s %14s { float:     %10s; }", ".$prefix", ".zspan ", "left"               ) );
	println( sprintf( "%10s %14s { box-sizing:%10s; }", ".$prefix", ".zspan ", "border-box"         ) );
	println( sprintf( "%10s %14s { padding:   %10s; }", ".$prefix", ".zspan ", "0 " . $z_gap . "px" ) );

	println();

	for ( $i=1; $i <= $n_columns; $i++ )
	{
		$w = spanWidth( $w_column, $w_gap, $i );

		println( sprintf( "%10s %14s { width:%8s }", ".$prefix", ".span$i", "$w" . "px;" ) );
	}
}

function printXSpans( $prefix, $w_column, $w_gap, $n_columns )
{
	println();

	for ( $i=1; $i <= $n_columns; $i++ )
	{
		$w = xspanWidth( $w_column, $w_gap, $i );

		println( sprintf( "%10s %14s { width:%8s }", ".$prefix", ".xspan$i", "$w" . "px;" ) );
	}
}

function printZSpans( $prefix, $w_column, $w_gap, $n_columns )
{
	println();

	for ( $i=1; $i <= $n_columns; $i++ )
	{
		//$w = xspanWidth( $w_column, $w_gap, $i );
		$w = 100 / $i;

		println( sprintf( "%10s %14s { width:%8s }", ".$prefix", ".zcol$i", "$w" . "%;" ) );
	}
}

function printOffsets( $prefix, $w_column, $w_gap, $n_columns )
{
	println();

	for ( $i=1; $i <= $n_columns; $i++ )
	{
		$w = offsetWidth( $w_column, $w_gap, $i );

		println( sprintf( "%10s %14s { margin-left:%8s }", ".$prefix", ".offset$i", "$w" . "px;" ) );
	}
}

function printElements( $prefix, $w_column, $w_gap, $n_columns, $w_padding )
{
	printTextFields( $prefix, $w_column, $w_gap, $n_columns, $w_padding );
	printButtons   ( $prefix, $w_column, $w_gap, $n_columns, $w_padding );
}

function printTextFields( $prefix, $w_column, $w_gap, $n_columns, $w_padding )
{
	$border_width = 2;

	println();

	//println( sprintf( "%10s %18s { padding-left:%s padding-right:%s }", ".$prefix", "INPUT[type='text'].text    ", "$w_gap" . "px;", "$w_gap" . "px;"  ) );
	//println( sprintf( "%10s %18s { padding-left:%s padding-right:%s }", ".$prefix", "INPUT[type='email'].text    ", "$w_gap" . "px;", "$w_gap" . "px;"  ) );
	//println( sprintf( "%10s %18s { padding-left:%s padding-right:%s }", ".$prefix", "INPUT[type='password'].text", "$w_gap" . "px;", "$w_gap" . "px;"  ) );

	println( sprintf( "%10s %14s { padding-left:%s padding-right:%s }",    ".$prefix",  ".text", "$w_padding" . "px;", "$w_padding" . "px;"  ) );
	println( sprintf( "%10s %14s { padding-left:%s padding-right:%s }",    ".$prefix", ".ztext", "$w_padding" . "px;", "$w_padding" . "px;"  ) );
	println( sprintf( "%10s %14s { box-sizing:border-box; width:100%%; }", ".$prefix", ".ztext" ) );

	for ( $i=1; $i <= $n_columns; $i++ )
	{
		$w = spanWidth( $w_column, $w_gap, $i ) - ($w_padding * 2) - $border_width;

		println( sprintf( "%10s %14s { width:%8s }", ".$prefix", ".text.span$i", "$w" . "px;" ) );
	}
}

function printButtons( $prefix, $w_column, $w_gap, $n_columns, $w_padding )
{
	println();

	println( sprintf( "%10s %14s { padding-left:%s padding-right:%s }",       ".$prefix", ".zbutton", "$w_padding" . "px;", "$w_padding" . "px;"  ) );
	println( sprintf( "%10s %14s { box-sizing:border-box; width:100%%; }", ".$prefix", ".zbutton" ) );

	for ( $i=1; $i <= $n_columns; $i++ )
	{
		$w = spanWidth( $w_column, $w_gap, $i ) - ($w_padding * 2);

		println( sprintf( "%10s %14s { width:%8s; padding-left:%8s; padding-right:%8s }", ".$prefix", "A.button.span$i", "$w" . "px", "$w_padding" . "px", "$w_padding" . "px" ) );
	}
}






function spanWidth( $w_column, $w_gap, $i )
{
	return ($i * $w_column) + (($i-1) * $w_gap);
}

function xspanWidth( $w_column, $w_gap, $i )
{
	return ($i * ($w_column + $w_gap));
}


function offsetWidth( $w_column, $w_gap, $i )
{
	return ($i * $w_column) + ($i * $w_gap) + $w_gap;
}

function println( $str = "" )
{
	echo( $str . "\n" );
}

?>
