<?php

class SitePage extends \Page
{
	protected $contentPath = CONTENT_PATH;

	function __construct()
	{
		parent::__construct();

		$this->addClass( "gs1080" );

		$this->setPageTitle( "Home" );
	}

	function render()
	{
		$http_status = self::GetContentFor( "http_status" );

		if ( ! string_startsWith( $http_status, "<!--" ) )
		{
			//header("HTTP/1.0 404 Not Found");
			header( $http_status );
		}

		$idtype = array_get( $_COOKIE, "idtype"     );
		$group  = array_get( $_COOKIE, "group_code" );

        $htm    = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "document", $idtype, $group ) );

		if ( $htm )
		{
			$this->out->println( $htm );
		}
		else
		{
			parent::render();
		}
	}

	function htmlContent( $out )
	{
		$idtype = array_get( $_COOKIE, "idtype" );
        $head   = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "head", $idtype ) );
        $body   = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "body", $idtype ) );

		if ( $head )
		{
			$out->printf( "\n" . $head );
			$out->printf( "\n" );
		}
		else
		{
			$this->headStart( $out );
			$this->headContent( $out );
			$this->headEnd( $out );
		}
		
		//	Is this needed any more?
		//
		//	$this->debug->writeBuffer();

		if ( $body )
		{
			$out->printf( "\n" . $body );
			$out->printf( "\n" );
		}
		else
		{
			$this->bodyStart    ( $out );
			$this->bodyContent  ( $out );
			$this->bodyEnd      ( $out );
		}
	}

	function title( $out )
	{
		$idtype = array_get( $_COOKIE, "idtype" );
        $title  = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "title", $idtype ) );

		if ( $title )
		{
			$out->printf( "\n" . $title );
			$out->printf( "\n" );
		}
		else
		{
			parent::title( $out );
		}
	}


	function meta( $out )
	{
		$idtype = array_get( $_COOKIE, "idtype" );
        $meta   = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "meta", $idtype ) );

		if ( $meta )
		{
			$out->printf( "\n" . $meta );
			$out->printf( "\n" );
		}
		else
		{
			header( "Content-Type: text/html; charset=UTF-8" );

			$out->println( "<meta charset='UTF-8'>" );
			$out->println( "<meta http-equiv='X-UA-Compatible' content='IE=edge'>" );
			$out->println( "<meta name='viewport' content='width=device-width'>" );
		}
	}

	function stylesheets( $out )
	{
		$idtype = array_get( $_COOKIE, "idtype" );
        $styles = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "styles", $idtype ) );

		if ( $styles )
		{
//            $styles = str_replace(   '%CLIENT_STYLE%',         CLIENT_STYLE, $styles );
//            $styles = str_replace(      '%RESOURCES%',            RESOURCES, $styles );
//
//            $styles = str_replace( 'href="/resources/styles/common', 'href="%RESOURCES_STYLES_COMMON%', $styles );
//            $styles = str_replace( "href='/resources/styles/common", "href='%RESOURCES_STYLES_COMMON%", $styles );
//
//            $styles = str_replace( 'href="/resources', 'href="' . RESOURCES, $styles );
//            $styles = str_replace( "href='/resources", "href='" . RESOURCES, $styles );
//
//            $styles = str_replace( 'href="%RESOURCES_STYLES_COMMON%', 'href="/resources/styles/common', $styles );
//            $styles = str_replace( "href='%RESOURCES_STYLES_COMMON%", "href='/resources/styles/common", $styles );

			$out->printf( "\n" . $styles );
			$out->printf( "\n" );
		}
	}

	function javascript( $out )
	{
		$idtype     = array_get( $_COOKIE, "idtype" );
        $javascript = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "javascript", $idtype ) );

		if ( $javascript )
		{
//            $javascript = str_replace(   '%CLIENT_STYLE%',         CLIENT_STYLE, $javascript );
//            $javascript = str_replace(      '%RESOURCES%',            RESOURCES, $javascript );
//            $javascript = str_replace( 'href="/resources', 'href="' . RESOURCES, $javascript );
//            $javascript = str_replace( "href='/resources", "href='" . RESOURCES, $javascript );

			$out->printf( "\n" . $javascript );
			$out->printf( "\n" );
		}
	}

	function bodyStart( $out )
	{
		$page_id     = $this->getPageId();
		$classes     = $this->getClasses();
		$pageyoffset = $this->getRequest( "pageyoffset" );
		$hostname    = $_SERVER["SERVER_NAME"];
		$browser     = "";

		if ( ! array_key_exists( "no-modal", $this->request ) )
		{
			$show = $this->getRequest( "show-modal" );
			$show = isset( $this->showModal ) ? $this->showModal : $show;
		}
		$out->inprint( "<body data-class='Page' id='$page_id' data-show='$show' class='$classes' data-browser='$browser' data-hostname='$hostname' data-pageyoffset='$pageyoffset'>" );
	}

	function bodyContent( $out )
	{
		$this->bodyMain     ( $out );
		$this->bodyFooter   ( $out );
		$this->bodyNav      ( $out );
		$this->bodyHeader   ( $out );
        $this->bodyDialogs  ( $out );
        $this->bodyTemplates( $out );
        $this->bodyMenu     ( $out );
	}

	function bodyMain( $out )
	{
		$group      = array_get( $_COOKIE, "group_code" );
		$idtype     = array_get( $_COOKIE, "idtype"     );

        $file_main       = Files::FindFilename( $this->getPageID(), self::MakeArray(       "main", $idtype, $group ) );
        $file_main_start = Files::FindFilename( $this->getPageID(), self::MakeArray( "main_start", $idtype, $group ) );
        $file_article    = Files::FindFilename( $this->getPageID(), self::MakeArray(    "article", $idtype, $group ) );
        $file_aside      = Files::FindFilename( $this->getPageID(), self::MakeArray(      "aside", $idtype, $group ) );

        $main       = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(       "main", $idtype, $group ) );
        $main_start = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "main_start", $idtype, $group ) );
        $article    = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(    "article", $idtype, $group ) );
        $aside      = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(      "aside", $idtype, $group ) );

		if ( $main && ! $article )
		{
			$out->printf( "\n" . $main );
			$out->printf( "\n" );
		}
        else
        if ( $main && (strlen( $file_main ) > strlen( $file_article )) )
        {
			$out->printf( "\n" . $main );
			$out->printf( "\n" );
        }
		else
		{
			if ( $main_start )
			{
				$out->inprint( "\n" . $main_start );
			}
			else
			{
				$out->inprint( "<main id='main' class='center responsive_page_width'>" );
			}

			if ( $aside )
			{
				$out->printf( "\n" . $aside );
				$out->printf( "\n" );

				$out->printf( "\n" . $article );
				$out->printf( "\n" );
			}
			else
            if ( $article )
			{
				$out->printf( "\n" . $article );
				$out->printf( "\n" );
			}
            else
            {
				$out->printf( "<!-- Could not find content -->\n" . $article );
            }

			$out->outprint( "</main>" );
		}
	}

	function bodyFooter( $out )
	{
		$idtype = array_get( $_COOKIE, "idtype" );
        $footer = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "footer", $idtype ) );

        if ( $footer )
        {
            $out->println( $footer );
        }
	}

	function setPageTitle( $title )
	{
		$idtype     = array_get( $_COOKIE, "idtype" );
        $site_title = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "title", $idtype ) );

		if ( $site_title )
		{
			$this->setTitle( $title . " | " . $site_title );
		}
		else
		{
			$this->setTitle( $title );
		}
	}

	function bodyHeader( $out )
	{
		$idtype = array_get( $_COOKIE, "idtype"     );
		$group  = array_get( $_COOKIE, "group_code" );

        $htm = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "header", $idtype, $group ) );

        if ( $htm ) $out->println( $htm );
	}

	function bodyNav( $out )
	{
		$idtype = array_get( $_COOKIE, "idtype"     );
		$group  = array_get( $_COOKIE, "group_code" );

        $nav_start   = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(   "nav_start", $idtype, $group ) );
        $nav_end     = "</nav>";

        $menus       = array();
        $menus[0]    = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(       "menu1", $idtype, $group ) );
        $menus[1]    = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(       "menu2", $idtype, $group ) );
        $menus[2]    = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(       "menu3", $idtype, $group ) );
        $menus[3]    = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(       "menu4", $idtype, $group ) );
        $menus[4]    = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(       "menu5", $idtype, $group ) );
        $menus[5]    = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(       "menu6", $idtype, $group ) );

        $breadcrumbs = Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "breadcrumbs", $idtype, $group ) );

        if ( $nav_start )
        {
            $n = count( $menus );
        
            for ( $i=0; $i < $n; $i++ )
            {
                $has_another_menu = (array_key_exists( $i + 1, $menus ) && ("" == $menus[$i + 1] ));
            
                if ( array_key_exists( $i, $menus ) && ("" != $menus[$i]) )
                {
                    $id = $i + 1;
                
                    $out->println( str_replace( "%nav_id%", "nav$id", $nav_start ) );
                    if ( array_key_exists( $i + 1, $menus ) && ("" == $menus[$i + 1] ) )
                    {
                        $out->println( $breadcrumbs );
                    }
                    $out->println( $menus[$i] );
                    $out->println( $nav_end   );
                }
            }
        }
        else
        {
            $out->println( Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(         "nav", $idtype ) ) );
            $out->println( Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(        "nav1", $idtype ) ) );
            $out->println( Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(        "nav2", $idtype ) ) );
        }
	}

	function bodyDialogs( $out )
	{
		$idtype = array_get( $_COOKIE, "idtype"     );

        $out->println( Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(  "dialog", $idtype ) ) );
        $out->println( Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "dialogs", $idtype ) ) );
	}

    function bodyTemplates( $out )
    {
		$idtype = array_get( $_COOKIE, "idtype"     );

        $out->println( Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray(  "template", $idtype ) ) );
        $out->println( Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "templates", $idtype ) ) );
    }

	function bodyMenu( $out )
	{
		$idtype = array_get( $_COOKIE, "idtype"     );

        $out->println( Content::FindHTMFragmentFor( $this->getPageID(), self::MakeArray( "menu", $idtype ) ) );
	}

    static function MakeArray( $name, $idtype, $group = "" )
    {
        $a = array();

        $a[] = $name;

        if ( $idtype )
        {
            $a[] = $idtype;
        }

        if ( $group )
        {
            $a[] = $group;
        }

        return $a;
    }

	/*
	 *	Trys to find content in the following order.
	 *
	 *	1)	PAGE_ID/$name-$idtype
	 *	2)	PAGE_ID/$name
	 *	3)	_site/$name-$idtype
	 *	4)	_site/$name
	 */

	function GetContentFor( $name )
	{
		$idtype = array_get( $_COOKIE, "idtype" );
		$htm    = "<!--";

		if ( "" != $idtype )
		{
			$htm = Content::getHTMFor( $this->getPageID(), "$name-" . $idtype, $this->contentPath );
		}

		if ( string_startsWith( $htm, "<!--" ) )
		{
			$htm = Content::getHTMFor( $this->getPageID(), "$name", $this->contentPath );
		}

		if ( string_startsWith( $htm, "<!--" ) && ("" != $idtype) )
		{
			$htm = Content::getHTMFor( "site", "$name-" . $idtype, $this->contentPath );
		}

		if ( string_startsWith( $htm, "<!--" ) )
		{
			$htm = Content::getHTMFor( "site", "$name", $this->contentPath );
		}

		if ( string_startsWith( $htm, "<!--" ) )
		{
			$htm = Content::getHTMFor( "site", "$name", COMMON_PATH );
		}

		if ( string_startsWith( $htm, "<!--" ) )
		{
			$htm = "<!-- Could not find file for $name -->";
		}

		return $htm;
	}
}
